##Duncan et al. ISME Submission
# -----------------
## Packages
# -----------------
library(ggplot2)
library(dplyr)
library(tidyr)
library(ggspatial)
library(ggOceanMaps)
library("ggbreak")

# -----------------
## Custom Functions
# -----------------

# Calculate PCA data points
# Stores row names of input (such as species names) in column 'obsnames'
# Outputs PCA data points for each Principal component as data frame with obsnames added
pca_format <- function(data) {
  PC <- prcomp(data, center = TRUE, scale. = TRUE)
  #Make a data frame of the main pca data stored in table "x" in the list from prcomp
  #Adds column 'obsnames' filled with the name of each row 
  data <- data.frame(PC$x)
  return(data)
}

# Calculate vectors for PCA (PC1 and PC2 only) based on data input
pca_vectors <- function(data) {
  PC <- prcomp(data, center = TRUE, scale. = TRUE)
  data <- data.frame(PC$x)
  
  #Calculate vectors
  x="PC1"
  y="PC2"
  datapc <- data.frame(varnames=rownames(PC$rotation), PC$rotation)
  mult <- min(
    (max(data[,y]) - min(data[,y])/(max(datapc[,y])-min(datapc[,y]))),
    (max(data[,x]) - min(data[,x])/(max(datapc[,x])-min(datapc[,x])))
  )
  datapc <- transform(datapc,
                      v1 = .7 * mult * (get(x)),
                      v2 = .7 * mult * (get(y))
  )
  return(datapc)
}

# Extract percent explained per principal component
# This function requires a vector (var) input apart from the original data, with numbers for each principal component it should output.
# The output is stored in a vector, so PC1 is in position 1 in the vector etc.
pca_prop_explained <- function(data,var) {
  #This is the same as the pca_format
  pca <- prcomp(data, center = TRUE, scale. = TRUE)
  
  eigs <- pca$sdev^2
  sum_eigs <- sum(eigs)
  prop <- c()
  for(i in 1:length(var)) {
    if(is.numeric(var[i])) {
      this_prop <- eigs[var[i]] / sum_eigs * 100
      prop[i] <- round(this_prop, digits = 1)
    } else {
      print("ERROR: Var must be integer.")
    }
  }
  return(prop)
}

##########################
# -----------------
## Figure 2 - Map
# -----------------
#Whole Arctic
basemap(limits = 65)

#Close up map of the sampling sites

coord<- 'Station.Coordinates'
basemap(limits = c(14, 18, 77.5, 78.7), bathymetry = FALSE, rotate = T) +
  geom_spatial_point(data = coord, aes(x = E, y = N) +
                       theme(panel.background = element_rect(fill = "lightblue"),
                             panel.ontop = FALSE)) +
  annotation_scale(location = "br") + 
  annotation_north_arrow(location = "tr", which_north = "true") 

basemap(expand.grid(lon = c(14, 18), lat = c(77.5, 78.7))) + 
  geom_spatial_point(data = coord, aes(x = E, y = N)) +
  theme(panel.background = element_rect(fill = '#CEEBFD'),
        panel.ontop = FALSE)  +
  annotation_scale(location = "br") + 
  annotation_north_arrow(location = "tr", which_north = "true") 

# -----------------
## Figure 3
# -----------------

df <- read.csv("output/processed_data/average_spectra.csv")
df$station_id= factor(df$station_id, levels=c('T2', 'VMF5', 'VMF4', 'VMF3', 'VMF2','VMF1'))
all_species <- unique(df$species)

#colour palette
cbp3 <- c("#c6c6c6", "#BBDEFB", "#42A5F5", "#1565C0", "#0D47A1", "#512DA8")

for(i in 1:length(all_species)) {
  
  this_species <- all_species[i]
  
  sub <- df %>% filter(species == this_species)
  
  p <- sub %>% filter(wavenumber > 1050 & wavenumber < 1100) %>%
    ggplot(aes(x = wavenumber, y = sig)) +
    geom_hline(yintercept = 0) +
    geom_line(aes(col = as.factor(station_id)), linewidth = 0.3) + 
    scale_x_reverse(breaks = seq(1000,3050,50)) +
    scale_x_break(c(2800,1800)) +
    scale_x_break(c(1675,1570)) +
    scale_color_manual(values = cbp3) +
    theme_bw() +
    theme(
      axis.text.x.top = element_blank(),
      axis.ticks.x.top = element_blank(),
      axis.line.x.top = element_blank(),
      axis.text.x = element_text(angle = 45, hjust = 1),
      axis.text.y = element_blank(),
      axis.ticks.y = element_blank(), 
      panel.grid = element_line(color = "#f9f9f9")
    ) +
    labs(y = "Smoothed and normalised signal", col = "Station ID", title = this_species)
  
  p
  
}


# -----------------
## Figure 4
# -----------------
#Convert dataframe from long to wide format
DF<- peaks_by_cell_log

#Ensure log_area_cell is numerical  
str(DF)
DF$log_area_cell<- as.numeric(as.character(DF$log_area_cell))
str(widedf2)
widedf <- DF %>% spread(compound, log_area_cell, fill = NA, convert = FALSE)

widedf<-  widedf %>%
  group_by(station_id, light, core, species, cell)  %>% 
  summarise(across(c("Unsaturated fatty acids", 
                     "Lipid CH-stretch",
                     "Saturated fatty acids",
                     "Saturated lipids",
                     "Ester carbonyl (I)",
                     "Protein (Amide II)",
                     "Phosphorylated molecules",
                     "Carbohydrates (II)",
                     "Carboxylated molecules",
                     "Silica"), ~sum(., na.rm = TRUE)))

widedf$light<- factor(widedf$light, levels = c("1.31","1.52","4.22","10.34","15.17", "23.18"))

#make sub data frames for each taxa summaries 
subpleuro <- widedf %>% filter(species == "Pleuro")
subnf <- widedf %>% filter(species == "Nfrigida")
subnav <- widedf %>% filter(species == "Navicula")
subento <- widedf %>% filter(species == "Ento")
subhaslea <- widedf %>% filter(species == "Haslea")

#repeat below for each taxa
entosummary <- subento %>% # the names of the new data frame and the data frame to be summarised
  group_by(light, species) %>%  # the grouping variable
  summarise(mean_unsfa = mean(`Unsaturated fatty acids`), 
            mean_sfa = mean(`Saturated fatty acids`), 
            mean_satlip = mean(`Saturated lipids`),
            mean_esterc = mean(`Ester carbonyl (I)`), 
            meanproamide2 = mean(`Protein (Amide II)`),
            meanlipstretch = mean(`Lipid CH-stretch`),
            meancarbox = mean(`Carboxylated molecules`), 
            meanphospho = mean(`Phosphorylated molecules`), 
            meancarb2 = mean(`Carbohydrates (II)`),
            meansilica = mean(`Silica`))
entosummarysd <- subento %>% # the names of the new data frame and the data frame to be summarised
  group_by(light, species) %>%  # the grouping variable
  summarise(sd_unsfa = sd(`Unsaturated fatty acids`),
            sd_sfa = sd(`Saturated fatty acids`), 
            sd_satlip = sd(`Saturated lipids`),
            sd_esterc = sd(`Ester carbonyl (I)`),
            sdproamide2 = sd(`Protein (Amide II)`), 
            sdlipstretch = sd(`Lipid CH-stretch`),
            sdcarbox = sd(`Carboxylated molecules`), 
            sdphospho = sd(`Phosphorylated molecules`), 
            sdcarb2 = sd(`Carbohydrates (II)`),
            sdsilica = sd(`Silica`))


#combine summaries
plotsummary<- bind_rows(entosummary, hasleasummary, navsummary, nfsummary, pleurosummary)
plotsummarysd<- bind_rows(entosummarysd, hasleasummarysd, navsummarysd, nfsummarysd, pleurosummarysd)

#convert to long format
plotsummarylongmean<-gather(plotsummary, Molecule, log_area, mean_unsfa:meansilica
                            ,factor_key=TRUE)
plotsummarylosd
plotsummarylongsd<-gather(plotsummarysd, Molecule, sd, sd_unsfa:sdsilica
                          ,factor_key=TRUE)
plotsummarylongsd = subset(plotsummarylongsd, select = -c(light,species,Molecule) )
plotsummaryall<- cbind(plotsummarylongmean, plotsummarylongsd)
plotsummaryall


#divide into photosynthetically derived and functional 
plotsummaryphoto <- filter(plotsummaryall, Molecule %in% c("mean_sfa","mean_unsfa", "mean_esterc", "meancarb2", "mean_satlip", "meanlipstretch"))
plotsummaryfunc <- filter(plotsummaryall, Molecule %in% c("meanphospho", "meanproamide2", "meancarbox"))

plotsummaryphoto
#make light numeric to ensure axis scales correctly 
plotsummaryphoto$light <- as.numeric(as.character(plotsummaryphoto$light))
plotsummaryfunc$light <- as.numeric(as.character(plotsummaryfunc$light))

plotsummaryphoto

###########
#Photosynthetically derived molecules (Part A)
###########
photoplot<- ggplot(plotsummaryphoto, aes(x = light, y = log_area, fill = Molecule, group = Molecule)) +
  geom_line(aes(colour = Molecule)) +
  geom_point(aes(colour = Molecule), size = 4, shape = 21) +
  xlab ("% Incoming PAR") +
  facet_wrap(~species,ncol = 5, scales= "free_y") +
  geom_smooth(aes(colour = Molecule, y = log_area, ymin = log_area-sd, ymax = log_area+sd), 
              stat="identity", alpha=0.2) + 
  scale_fill_manual(values=c("#C05780", "#EBB8BD",  "#CCA8E3", "#00B0BA", "darkseagreen", "peru")) +
  scale_colour_manual(values=c("#C05780", "#EBB8BD", "#CCA8E3","#00B0BA", "darkseagreen","peru")) +
  scale_y_continuous(limits = c(-1, 2)) +
  scale_x_continuous(limits = c(0, 25)) +
  theme(axis.text.y = element_text(colour = "black", size = 10), 
        #theme(axis.text.y = element_blank(), 
        axis.text.x = element_text(colour = "black", size = 10), 
        legend.text = element_text(size = 10, face ="bold", colour ="black"), 
        legend.position = "right",
        axis.title.x = element_text(face = "bold", size = 10, colour = "black"), 
        legend.title = element_text(size = 10, colour = "black", face = "bold"), 
        strip.background = element_blank(), 
        panel.background = element_blank(), panel.border = element_rect(colour = "black", fill = NA, size = 1.2),
        legend.key=element_blank())  
photoplot

###########
#Functional molecules (part b)
###########
functionalplot<- ggplot(plotsummaryfunc, aes(x = light, y = log_area, fill = Molecule, group = Molecule)) +
  geom_line(aes(colour = Molecule)) +
  geom_point(aes(colour = Molecule), size = 4, shape = 21) +
  xlab ("% Incoming PAR") +
  facet_wrap(~species,ncol = 5, scales= "free_y") +
  scale_y_continuous(limits = c(-1, 2), labels = scales::label_number(accuracy = 1)) +
  scale_x_continuous(limits = c(0, 25)) +
  geom_smooth(aes(colour = Molecule, y = log_area, ymin = log_area-sd, ymax = log_area+sd), 
              stat="identity", alpha=0.2) + 
  scale_fill_manual(values=c("#BA3F1D", "#0065A2", "#3D7344"))+
  scale_colour_manual(values=c("#BA3F1D", "#0065A2", "#3D7344")) +
  theme(axis.text.y = element_text(colour = "black", size = 10), 
        #theme(axis.text.y = element_blank(),  
        axis.text.x = element_text(colour = "black", size = 10), 
        legend.text = element_text(size = 10, face ="bold", colour ="black"), 
        legend.position = "right",
        axis.title.x = element_text(face = "bold", size = 10, colour = "black"), 
        legend.title = element_text(size = 10, colour = "black", face = "bold"), 
        strip.background = element_blank(), 
        panel.background = element_blank(), panel.border = element_rect(colour = "black", fill = NA, size = 1.2),
        legend.key=element_blank())  
functionalplot

# -----------------
## Figure 5 A
# -----------------
widedf
#Create subset of data with just necessary columns and then spread data
dtw <- widedf %>% # the names of the new data frame and the data frame to be summarised
  group_by(light, species) %>%  # the grouping variable
  summarise(mean_unsfa = mean(`Unsaturated fatty acids`), 
            mean_sfa = mean(`Saturated fatty acids`), 
            mean_satlip = mean(`Saturated lipids`),
            mean_esterc = mean(`Ester carbonyl (I)`), 
            meanproamide2 = mean(`Protein (Amide II)`),
            meanlipstretch = mean(`Lipid CH-stretch`),
            meancarbox = mean(`Carboxylated molecules`), 
            meanphospho = mean(`Phosphorylated molecules`), 
            meancarb2 = mean(`Carbohydrates (II)`),
            meansilica = mean(`Silica`))
dtw

# 1
#Create limited data frame that only includes data columns
dat <- dtw[,3:length(names(dtw))]
dat[is.na(dat)]<-0
dat

# 2
#Get PCA data points (note structure of data = one column per principal component and one for row ids)
pca <- pca_format(dat)

# 3
#Add row identifies as needed
dtw
pca$species <- dtw$species
pca$light <- dtw$light
pca

# 4 
#Extract principal component proportions
prop <- pca_prop_explained(dat,c(1,2))

# 5 
#Extract vector information for plot
vectors<- pca_vectors(dat)
dat
vectors
rownames(vectors)  <- c("Unsaturated fatty acids",
                        "Saturated fatty acids", "Saturated lipids",
                        "Lipid (Ester carbonyl)", "Protein (Amide II)", "Lipid CH-stretch", 
                        "Carboxylated Molecules", "Phosphorylated Molecules", 
                        "Carbohydrate")


#PCA plot layout
str(pca)
pc2
pca$light <- factor(pca$light, levels = c("1.31","1.52","4.22","10.34","15.17", "23.18"))
pc2 <- ggplot(pca, aes(x = PC1, y = PC2)) + 
  geom_point(aes(fill = light, shape = species), size = 3, alpha = 0.8, show.legend = TRUE) +  
  scale_shape_manual(values=c(21,22,23,24,25)) +
  scale_color_manual(values=c("#512DA8", "#0D47A1","#1565C0","#42A5F5", "#BBDEFB", "grey84")) +
  scale_fill_manual(values=c("#512DA8", "#0D47A1","#1565C0","#42A5F5", "#BBDEFB","grey84")) +
  stat_ellipse(aes(x=PC1, y=PC2, group = light, colour = light), size = 0.2, show.legend = FALSE) +
  labs(x = paste0(sprintf("PC1 (%s",prop[1]),"%)"), y = paste0(sprintf("PC2 (%s",prop[2]),"%)"))
#Add vectors to plot
pcv <- pc2 + 
  coord_equal() + 
  geom_text(data = vectors, aes(x = v1*1.2, y = v2*1.2, label = varnames), size = 1.5, vjust = 0, hjust = 0, alpha = 1, color = 1) +
  geom_segment(data = vectors, aes(x = 0, y = 0, xend = v1*2, yend = v2*2), arrow = arrow(length = unit(0.2,"cm")), size = 0.2, alpha = 1, color = 1) +
  theme(panel.grid.minor = element_blank(), panel.grid.major = element_blank(), panel.background = element_rect(linetype = "solid", colour = 1, fill = "white")) 

#Show plot
pcv


# -----------------
## Figure 5 B 
# -----------------

library(corrplot)
widedf_corr<- widedf
widedf_corr  <- widedf_corr[,6:ncol(widedf_corr)]

widedf_corr<- widedf_corr[, c("Carbohydrate", "Carboxylated molecules", "Lipid (CH-Stretch)", "Lipid (Ester carbonyl)", "Phosphorylated Molecules", "Protein Amide (II)",
                              "Saturated Lipid", "Saturated fatty acids", "Unsaturated fatty acids")]

widedf_corr [is.na(widedf_corr )] <- 0
M<-cor(widedf_corr, method="spearman" )

corrplot(M, method="circle", type = "upper", tl.col="black", tl.srt=45, tl.cex = 0.5, number.cex = 0.5)


# -----------------
## Figure 6
# -----------------
#Divide DF into 'High light' and 'low light' sites
DFHL<- filter(widedf, station_id %in% c("T2", "VMF5", "VMF4"))
DFLL<- filter(widedf, station_id %in% c("VM3", "VM2", "VM1"))

#Lipid vs Protein per species
widedf
lippro<- ggplot(data = widedf, aes(protein.amide.2, ester.carbonyl, group = species, fill =  light)) +
  geom_point(size = 3, pch = 21, colour = "black", stroke = 0.3) + 
  geom_smooth(method = "lm", se=TRUE, color="black", fill = "lightskyblue", formula = y ~ x, size = 1, aes(group=1), data = DFHL) +
  geom_smooth(method = "lm", se=TRUE, color="black", fill = "#512DA8", formula = y ~ x, size = 1, aes(group=1), data = DFLL) +
  geom_abline(colour='gray', linetype = "dashed") + lims(x = c(0,3), y = c(0,3)) +
  facet_wrap(~species,ncol = 5, scales= "free") +
  scale_colour_manual(breaks = c("1.31", "1.52", "4.22", "10.34", "15.17", "23.18"), 
                      values=c("#512DA8", "#0D47A1","#1565C0","#42A5F5", "#BBDEFB", "#DDDDE0")) +
  scale_fill_manual(breaks = c("1.31", "1.52", "4.22", "10.34", "15.17", "23.18"), 
                    values=c("#512DA8", "#0D47A1","#1565C0","#42A5F5", "#BBDEFB", "#DDDDE0")) +
  xlab("log\U2081 Protein (Amide II)")+ ylab ("log\U2081 (Ester carbonyl) Lipid") +
  scale_y_continuous(limits = c(0, 2)) +
  scale_x_continuous(limits = c(0, 2)) +
  theme(panel.background = element_rect(fill = "white", colour = "black"),
        strip.background = element_rect(fill = "white", colour = "black"),
        panel.border = element_rect(colour = "black", fill = NA, size = 0.5),
        #axis.text.y = element_blank(),
        legend.key = element_rect(fill="NA"))+
  theme(strip.text.x = element_text(size = 7, colour = "black", face = "italic"))
lippro

#Protein vs Carbohydrate per species
procarb<- ggplot(data = widedf, aes(protein.amide.2, carb2, group = species, fill =  light)) +
  geom_point(size = 3, pch = 21, colour = "black", stroke = 0.3) + 
  geom_smooth(method = "lm", se=TRUE, color="black", fill = "lightskyblue", formula = y ~ x, size = 1, aes(group=1), data = DFHL) +
  geom_smooth(method = "lm", se=TRUE, color="black", fill = "#512DA8", formula = y ~ x, size = 1, aes(group=1), data = DFLL) +
  geom_abline(colour='gray', linetype = "dashed") + lims(x = c(0,3), y = c(0,3)) +
  facet_wrap(~species,ncol = 5, scales= "free") +
  scale_colour_manual(breaks = c("1.31", "1.52", "4.22", "10.34", "15.17", "23.18"), 
                      values=c("#512DA8", "#0D47A1","#1565C0","#42A5F5", "#BBDEFB", "#DDDDE0")) +
  scale_fill_manual(breaks = c("1.31", "1.52", "4.22", "10.34", "15.17", "23.18"), 
                    values=c("#512DA8", "#0D47A1","#1565C0","#42A5F5", "#BBDEFB", "#DDDDE0")) +
  xlab("log\U2081 Protein (Amide II)")+ ylab ("log\U2081 Carbohydrate") +
  scale_y_continuous(limits = c(0, 1.5)) +
  scale_x_continuous(limits = c(0, 1.5)) +
  theme(panel.background = element_rect(fill = "white", colour = "black"),
        strip.background = element_rect(fill = "white", colour = "black"),
        panel.border = element_rect(colour = "black", fill = NA, size = 0.5),
        legend.key = element_rect(fill="NA")) +
  theme(strip.text.x = element_text(size = 7, colour = "black", face = "italic"))
procarb

##Lipid vs Carbohydrate vs Protein

#Lipid vs Protein Ratio per species
widedf
lippro<- ggplot(data = widedf, aes(carb2, ester.carbonyl, group = species, fill =  light)) +
  geom_point(size = 3, pch = 21, colour = "black", stroke = 0.3) + 
  geom_smooth(method = "lm", se=TRUE, color="black", fill = "lightskyblue", formula = y ~ x, size = 1, aes(group=1), data = DFHL) +
  #geom_smooth(method = "lm", se=TRUE, color="black", fill = "#512DA8", formula = y ~ x, size = 1, aes(group=1), data = DFLL) +
  geom_abline(colour='gray', linetype = "dashed") + lims(x = c(0,3), y = c(0,3)) +
  facet_wrap(~species,ncol = 5, scales= "free") +
  scale_colour_manual(breaks = c("1.31", "1.52", "4.22", "10.34", "15.17", "23.18"), 
                      values=c("#512DA8", "#0D47A1","#1565C0","#42A5F5", "#BBDEFB", "#DDDDE0")) +
  scale_fill_manual(breaks = c("1.31", "1.52", "4.22", "10.34", "15.17", "23.18"), 
                    values=c("#512DA8", "#0D47A1","#1565C0","#42A5F5", "#BBDEFB", "#DDDDE0")) +
  xlab("log\U2081 Carbohydrate")+ ylab ("log\U2081 (Ester carbonyl) Lipid") +
  scale_y_continuous(limits = c(0, 2)) +
  scale_x_continuous(limits = c(0, 2)) +
  theme(panel.background = element_rect(fill = "white", colour = "black"),
        strip.background = element_rect(fill = "white", colour = "black"),
        panel.border = element_rect(colour = "black", fill = NA, size = 0.5),
        legend.key = element_rect(fill="NA"))+
  theme(strip.text.x = element_text(size = 7, colour = "black", face = "italic"))
lippro


# -----------------
## Figure 7
# -----------------

DF_silica <- plotsummaryall %>% filter(Molecule == "meansilica")
DF_silica$light <- as.numeric(as.character(DF_silica$light))

DF_silica_ento <- filter(DF_silica, species %in% c("Ento"))
DF_silica_nav<- filter(DF_silica, species %in% c("Navicula"))
DF_silica_nf<- filter(DF_silica, species %in% c("Nfrigida"))
DF_silica_haslea<- filter(DF_silica, species %in% c("Haslea"))
DF_silica_pleuro<- filter(DF_silica, species %in% c("Pleuro"))

silicap<- ggplot(DF_silica, aes(x= light, y = log_area_cell , color =species, group = species, fill =species)) +  
  geom_jitter(size = 3,pch = 21, colour = "black", stroke = 0.2, width = 0.3) +
  scale_colour_manual(breaks = c("Ento", "Haslea", "Navicula", "Nfrigida", "Pleuro"), 
                      values=c("#8EAC7C", "#8EAC7C","#8EAC7C","#8EAC7C", "#8EAC7C")) +
  scale_fill_manual(breaks = c("Ento", "Haslea", "Navicula", "Nfrigida", "Pleuro"), 
                    values=c("#8EAC7C", "#8EAC7C","#8EAC7C","#8EAC7C", "#8EAC7C")) +
  facet_wrap(~species,ncol = 5, scales= "free_y") +
  xlab ("% Incoming PAR") +
  ylab ("Log Area Silica") +
  geom_smooth(method = "lm", se=TRUE, color="black", fill = "#8EAC7C", formula = y ~ x, size = 1, aes(group=1), data = DF_silica_ento) +
  geom_smooth(method = "lm", se=TRUE, color="black", fill = "#8EAC7C", formula = y ~ x, size = 1, aes(group=1), data = DF_silica_nav) +
  geom_smooth(method = "lm", se=TRUE, color="black", fill = "#8EAC7C", formula = y ~ poly(x,2), size = 1, aes(group=1), data = DF_silica_nf)+
  geom_smooth(method = "lm", se=TRUE, color="black", fill = "#8EAC7C", formula =  y ~ x, size = 1, aes(group=1), data = DF_silica_haslea2) +
  geom_smooth(method = "lm", se=TRUE, color="black", fill = "#8EAC7C", formula = y ~ x, size = 1, aes(group=1), data = DF_silica_pleuro) +
  theme(axis.text.x = element_text(colour = "black", size = 10),
        axis.text.y = element_text(colour = "black", size = 10), 
        legend.text = element_text(size = 10, face ="bold", colour ="black"), 
        legend.position = "right",
        axis.title.x = element_text(size = 10, colour = "black"), 
        legend.title = element_blank(), 
        panel.background = element_blank(), panel.border = element_rect(colour = "black", fill = NA, size = 1.2))
silicap


